==> jboss-ewp-src-5.1.0.zip: jboss-ewp-5.1-src/jboss-as-web/thirdparty/licenses/BSD - bsd-license.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en" dir="ltr">
  <head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="shortcut icon" href="/files/garland_favicon.png" type="image/x-icon" />
<!--[if lt IE 7]>
<script defer type="text/javascript" src="/files/pngfix.js"></script>
<![endif]-->
    <title>Open Source Initiative OSI - The BSD License:Licensing | Open Source Initiative</title>
    <link type="text/css" rel="stylesheet" media="all" href="/modules/aggregator/aggregator.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/node/node.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/defaults.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/system.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/system-menus.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/user/user.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/comment/comment.css?k" />
<link type="text/css" rel="stylesheet" media="all" href="/files/color/garland-4208c934/style.css?k" />
<link type="text/css" rel="stylesheet" media="print" href="/themes/garland/print.css?k" />
        <!--[if lt IE 7]>
      <link type="text/css" rel="stylesheet" media="all" href="/themes/garland/fix-ie.css" />    <![endif]-->
  </head>
  <body class="sidebar-left">

<!-- Layout -->
  <div id="header-region" class="clear-block"></div>

    <div id="wrapper">
    <div id="container" class="clear-block">

      <div id="header">
        <div id="logo-floater">
        <h1><a href="/" title="Open Source Initiative"><img src="/files/garland_logo.png" alt="Open Source Initiative" id="logo" /><span>Open Source Initiative</span></a></h1>        </div>

                                                    
      </div> <!-- /header -->

              <div id="sidebar-left" class="sidebar">
          <div class="block block-theme"><form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="search-theme-form">
<div><div id="search" class="container-inline">
  <div class="form-item" id="edit-search-theme-form-1-wrapper">
 <label for="edit-search-theme-form-1">Search this site: </label>
 <input type="text" maxlength="128" name="search_theme_form" id="edit-search-theme-form-1" size="15" value="" title="Enter the terms you wish to search for." class="form-text" />
</div>
<input type="submit" name="op" id="edit-submit-2" value="Search"  class="form-submit" />
<input type="hidden" name="form_build_id" id="form-4504f1a37b9d4dc16e18106c8e113acf" value="form-4504f1a37b9d4dc16e18106c8e113acf"  />
<input type="hidden" name="form_id" id="edit-search-theme-form" value="search_theme_form"  />
</div>

</div></form>
</div>          <div id="block-user-1" class="clear-block block block-user">

  <h2>Navigation</h2>

  <div class="content"><ul class="menu"><li class="collapsed first"><a href="/about" title="About the Open Source Initiative">About the OSI</a></li>
<li class="collapsed"><a href="/docs/osd" title="The actual OSD defining what constitutes an Open Source licence">The Open Source Definition</a></li>
<li class="collapsed"><a href="/licenses/index.html">Open Source Licenses</a></li>
<li class="collapsed"><a href="/osr-intro" title="Open Standards Requirement for Software">Open Standards</a></li>
<li class="leaf"><a href="/osi-open-source-education" title="OSI&#039;s Open Source Education Initiative and Activities">Open Source Education</a></li>
<li class="collapsed"><a href="/lists" title="The virtual committees where the OSI&#039;s work gets done">Mailing lists</a></li>
<li class="collapsed"><a href="/help" title="Resources for questions and further exploration">Getting Help</a></li>
<li class="leaf"><a href="/donate" title="The OSI is a 501(c)3.  Donations are tax-deductible on US income taxes.">Donate to the OSI</a></li>
<li class="leaf last"><a href="/ToS" title="Rules for posting content on this site">Terms of Service</a></li>
</ul></div>
</div>
<div id="block-block-2" class="clear-block block block-block">


  <div class="content"><ul>
<li class="leaf">OSI Board <a href="mailto:osi@opensource.org">email</a></li>
<li class="leaf">Site Admin <a href="mailto:webmaster@opensource.org">email</a></li>
</ul></div>
</div>
        </div>
      
      <div id="center"><div id="squeeze"><div class="right-corner"><div class="left-corner">
          <div class="breadcrumb"><a href="/">Home</a></div>                              <h2>Open Source Initiative OSI - The BSD License:Licensing</h2>                                                  <div class="clear-block">
            <div id="node-45" class="node">



  
  <div class="content clear-block">
        <img style="float: right; margin: 1em;" width="100" height="137" alt="[OSI Approved License]" src="/trademarks/opensource/
OSI-Approved-License-100x137.png"/>
        
    <h1>The BSD License</h1>

    <blockquote>
      <p>The following is a BSD license template. To generate your own license, change the values of OWNER, ORGANIZATION and YEAR from their original values as given here, and substitute your own. Also, you may optionally omit clause 3 and still be OSD conformant.</p>

      <p><em>Note:</em> On January 9th, 2008 the OSI Board approved the "Simplified BSD License" variant used by <a href="http://www.freebsd.org/copyright/freebsd-license.html">FreeBSD</a> and others, which omits the final "no-endorsement" clause and is thus roughly equivalent to the <a href="mit-license.html">MIT License</a>.</p>

      <p><em>Historical Note</em>: The original license used on BSD Unix had four clauses. The advertising clause (the third of four clauses) required you to acknowledge use of U.C. Berkeley code in your advertising of any product using that code. It was officially <a href="ftp://ftp.cs.berkeley.edu/pub/4bsd/README.Impt.License.Change">rescinded</a> by the Director of the Office of Technology Licensing of the University of California on July 22nd, 1999. He states that clause 3 is "hereby deleted in its entirety." The four clause license has not been approved by OSI. The license below does not contain the advertising clause.</p>

      <p>This prelude is not part of the license.</p>
    </blockquote>

    <p>&lt;OWNER&gt; = Regents of the University of California<br />
     &lt;ORGANIZATION&gt; = University of California, Berkeley<br />
     &lt;YEAR&gt; = 1998</p>

    <p>In the original BSD license, both occurrences of the phrase "COPYRIGHT HOLDERS AND CONTRIBUTORS" in the disclaimer read "REGENTS AND CONTRIBUTORS".</p>

    <p>Here is the license template:</p>

    <p>Copyright (c) &lt;YEAR&gt;, &lt;OWNER&gt;<br />
     All rights reserved.</p>

    <p>Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:</p>

    <ul>
      <li>Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.</li>

      <li>Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.</li>

      <li>Neither the name of the &lt;ORGANIZATION&gt; nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.</li>
    </ul>

    <p>THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</p>
    </div>

  <div class="clear-block">
    <div class="meta">
        </div>

      </div>

</div>
<div id="comments">
  <h2 class="comments">Comments</h2><form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="comment-controls">
<div><div class="box">

  <h2>Comment viewing options</h2>

  <div class="content"><div class="container-inline"><input type="hidden" name="form_build_id" id="form-d53c47cabec18d51033516bcc4e6d38e" value="form-d53c47cabec18d51033516bcc4e6d38e"  />
<input type="hidden" name="form_id" id="edit-comment-controls" value="comment_controls"  />
<div class="form-item" id="edit-mode-wrapper">
 <select name="mode" class="form-select" id="edit-mode" ><option value="1">Flat list - collapsed</option><option value="2">Flat list - expanded</option><option value="3">Threaded list - collapsed</option><option value="4" selected="selected">Threaded list - expanded</option></select>
</div>
<div class="form-item" id="edit-order-wrapper">
 <select name="order" class="form-select" id="edit-order" ><option value="1" selected="selected">Date - newest first</option><option value="2">Date - oldest first</option></select>
</div>
<div class="form-item" id="edit-comments-per-page-wrapper">
 <select name="comments_per_page" class="form-select" id="edit-comments-per-page" ><option value="10">10 comments per page</option><option value="30">30 comments per page</option><option value="50" selected="selected">50 comments per page</option><option value="70">70 comments per page</option><option value="90">90 comments per page</option><option value="150">150 comments per page</option><option value="200">200 comments per page</option><option value="250">250 comments per page</option><option value="300">300 comments per page</option></select>
</div>
<input type="submit" name="op" id="edit-submit" value="Save settings"  class="form-submit" />
</div><div class="description">Select your preferred way to display the comments and click "Save settings" to activate your changes.</div></div>
</div>

</div></form>
<a id="comment-1294"></a>
<div class="comment comment-published odd">

  <div class="clear-block">
      <span class="submitted">Wed, 2010-03-31 14:02 — rixius</span>
  
  
  
    <h3><a href="/licenses/bsd-license.php#comment-1294" class="active">Sub Licensing</a></h3>

    <div class="content">
      <p>If you are deriving an application from an application licensed with this new BSD license, how does the process work?<br />
the deriving is making substansial changes.</p>
          </div>
  </div>

  </div>
<form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="comment-controls-1">
<div><div class="box">

  <h2>Comment viewing options</h2>

  <div class="content"><div class="container-inline"><input type="hidden" name="form_build_id" id="form-15219b8490965fe6be0702884be1a76b" value="form-15219b8490965fe6be0702884be1a76b"  />
<input type="hidden" name="form_id" id="edit-comment-controls-1" value="comment_controls"  />
<div class="form-item" id="edit-mode-1-wrapper">
 <select name="mode" class="form-select" id="edit-mode-1" ><option value="1">Flat list - collapsed</option><option value="2">Flat list - expanded</option><option value="3">Threaded list - collapsed</option><option value="4" selected="selected">Threaded list - expanded</option></select>
</div>
<div class="form-item" id="edit-order-1-wrapper">
 <select name="order" class="form-select" id="edit-order-1" ><option value="1" selected="selected">Date - newest first</option><option value="2">Date - oldest first</option></select>
</div>
<div class="form-item" id="edit-comments-per-page-1-wrapper">
 <select name="comments_per_page" class="form-select" id="edit-comments-per-page-1" ><option value="10">10 comments per page</option><option value="30">30 comments per page</option><option value="50" selected="selected">50 comments per page</option><option value="70">70 comments per page</option><option value="90">90 comments per page</option><option value="150">150 comments per page</option><option value="200">200 comments per page</option><option value="250">250 comments per page</option><option value="300">300 comments per page</option></select>
</div>
<input type="submit" name="op" id="edit-submit-1" value="Save settings"  class="form-submit" />
</div><div class="description">Select your preferred way to display the comments and click "Save settings" to activate your changes.</div></div>
</div>

</div></form>
</div>
          </div>
                    <div id="footer"><a rel="license" href="http://creativecommons.org/licenses/by/2.5/"><img alt="Creative Commons License" src="http://i.creativecommons.org/l/by/2.5/88x31.png" /></a><br />Opensource.org site content is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/2.5/">Creative Commons Attribution 2.5  License</a>.
	
		
	
	|  <a href="../ToS">Terms of Service</a><div id="block-block-7" class="clear-block block block-block">


  <div class="content"><script src="http://www.google-analytics.com/urchin.js" type="text/javascript">
</script>
<script type="text/javascript">
_uacct = "UA-3916956-1";
urchinTracker();
</script></div>
</div>
</div>
      </div></div></div></div> <!-- /.left-corner, /.right-corner, /#squeeze, /#center -->

      
    </div> <!-- /container -->
  </div>
<!-- /layout -->

    </body>
</html>

==> jboss-ewp-src-5.1.2.zip: jboss-ewp-5.1-src/jboss-as-web/thirdparty/licenses/BSD - bsd-license.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en" dir="ltr">
  <head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="shortcut icon" href="/files/garland_favicon.png" type="image/x-icon" />
<!--[if lt IE 7]>
<script defer type="text/javascript" src="/files/pngfix.js"></script>
<![endif]-->
    <title>Open Source Initiative OSI - The BSD License:Licensing | Open Source Initiative</title>
    <link type="text/css" rel="stylesheet" media="all" href="/modules/aggregator/aggregator.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/node/node.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/defaults.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/system.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/system/system-menus.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/user/user.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/sites/all/modules/mollom/mollom.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/modules/comment/comment.css?V" />
<link type="text/css" rel="stylesheet" media="all" href="/files/color/garland-4208c934/style.css?V" />
<link type="text/css" rel="stylesheet" media="print" href="/themes/garland/print.css?V" />
    <script type="text/javascript" src="/misc/jquery.js?V"></script>
<script type="text/javascript" src="/misc/drupal.js?V"></script>
<script type="text/javascript" src="/sites/all/modules/mollom/mollom.js?V"></script>
<script type="text/javascript">
<!--//--><![CDATA[//><!--
jQuery.extend(Drupal.settings, { "basePath": "/" });
//--><!]]>
</script>
    <!--[if lt IE 7]>
      <link type="text/css" rel="stylesheet" media="all" href="/themes/garland/fix-ie.css" />    <![endif]-->
  </head>
  <body class="sidebar-left">

<!-- Layout -->
  <div id="header-region" class="clear-block"></div>

    <div id="wrapper">
    <div id="container" class="clear-block">

      <div id="header">
        <div id="logo-floater">
        <h1><a href="/" title="Open Source Initiative"><img src="/files/garland_logo.png" alt="Open Source Initiative" id="logo" /><span>Open Source Initiative</span></a></h1>        </div>

                                                    
      </div> <!-- /header -->

              <div id="sidebar-left" class="sidebar">
          <div class="block block-theme"><form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="search-theme-form">
<div><div id="search" class="container-inline">
  <div class="form-item" id="edit-search-theme-form-1-wrapper">
 <label for="edit-search-theme-form-1">Search this site: </label>
 <input type="text" maxlength="128" name="search_theme_form" id="edit-search-theme-form-1" size="15" value="" title="Enter the terms you wish to search for." class="form-text" />
</div>
<input type="submit" name="op" id="edit-submit-2" value="Search"  class="form-submit" />
<input type="hidden" name="form_build_id" id="form-b956fcc932bdcb85d55d92925cfa7711" value="form-b956fcc932bdcb85d55d92925cfa7711"  />
<input type="hidden" name="form_id" id="edit-search-theme-form" value="search_theme_form"  />
</div>

</div></form>
</div>          <div id="block-user-1" class="clear-block block block-user">

  <h2>Navigation</h2>

  <div class="content"><ul class="menu"><li class="collapsed first"><a href="/about" title="About the Open Source Initiative">About the OSI</a></li>
<li class="collapsed"><a href="/docs/osd" title="The actual OSD defining what constitutes an Open Source licence">The Open Source Definition</a></li>
<li class="collapsed"><a href="/licenses/index.html">Open Source Licenses</a></li>
<li class="collapsed"><a href="/osr-intro" title="Open Standards Requirement for Software">Open Standards</a></li>
<li class="leaf"><a href="/osi-open-source-education" title="OSI&#039;s Open Source Education Initiative and Activities">Open Source Education</a></li>
<li class="collapsed"><a href="/lists" title="The virtual committees where the OSI&#039;s work gets done">Mailing lists</a></li>
<li class="collapsed"><a href="/help" title="Resources for questions and further exploration">Getting Help</a></li>
<li class="collapsed"><a href="/donate" title="The OSI is a 501(c)3.  Donations are tax-deductible on US income taxes.">Donate to the OSI</a></li>
<li class="leaf last"><a href="/ToS" title="Rules for posting content on this site">Terms of Service</a></li>
</ul></div>
</div>
<div id="block-block-2" class="clear-block block block-block">


  <div class="content"><ul>
<li class="leaf">OSI Board <a href="mailto:osi@opensource.org">email</a></li>
<li class="leaf">Site Admin <a href="mailto:webmaster@opensource.org">email</a></li>
</ul></div>
</div>
        </div>
      
      <div id="center"><div id="squeeze"><div class="right-corner"><div class="left-corner">
          <div class="breadcrumb"><a href="/">Home</a></div>                              <h2>Open Source Initiative OSI - The BSD License:Licensing</h2>                                                  <div class="clear-block">
            <div id="node-45" class="node">



  
  <div class="content clear-block">
        <img style="float: right; margin: 1em;" width="100" height="137" alt="[OSI Approved License]" src="/trademarks/opensource/OSI-Approved-License-100x137.png"/>
            <h1>The BSD 2-Clause License</h1>

    <blockquote>
      <p>The following is a BSD 2-Clause license template. To generate your own license, change the values of OWNER, ORGANIZATION and YEAR from their original values as given here, and substitute your own.</p>

      <p><em>Note: see also the <a href="/licenses/BSD-3-Clause" >BSD-3-Clause</a> license.</em></p>

      <p>This prelude is not part of the license.</p>
    </blockquote>

    <p>&lt;OWNER&gt; = Regents of the University of California<br />
     &lt;ORGANIZATION&gt; = University of California, Berkeley<br />
     &lt;YEAR&gt; = 1998</p>

    <p>In the original BSD license, both occurrences of the phrase "COPYRIGHT HOLDERS AND CONTRIBUTORS" in the disclaimer read "REGENTS AND CONTRIBUTORS".</p>

    <p>Here is the license template:</p>

    <p>Copyright (c) &lt;YEAR&gt;, &lt;OWNER&gt;<br />
     All rights reserved.</p>

    <p>Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:</p>

    <ul>
      <li>Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.</li>

      <li>Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.</li>
    </ul>

    <p>THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</p>

    </div>

  <div class="clear-block">
    <div class="meta">
        </div>

      </div>

</div>
<div id="comments">
  <h2 class="comments">Comments</h2><form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="comment-controls">
<div><div class="box">

  <h2>Comment viewing options</h2>

  <div class="content"><div class="container-inline"><input type="hidden" name="form_build_id" id="form-13c3ab832008b68f3454b9ad62d86889" value="form-13c3ab832008b68f3454b9ad62d86889"  />
<input type="hidden" name="form_id" id="edit-comment-controls" value="comment_controls"  />
<div class="form-item" id="edit-mode-wrapper">
 <select name="mode" class="form-select" id="edit-mode" ><option value="1">Flat list - collapsed</option><option value="2">Flat list - expanded</option><option value="3">Threaded list - collapsed</option><option value="4" selected="selected">Threaded list - expanded</option></select>
</div>
<div class="form-item" id="edit-order-wrapper">
 <select name="order" class="form-select" id="edit-order" ><option value="1" selected="selected">Date - newest first</option><option value="2">Date - oldest first</option></select>
</div>
<div class="form-item" id="edit-comments-per-page-wrapper">
 <select name="comments_per_page" class="form-select" id="edit-comments-per-page" ><option value="10">10 comments per page</option><option value="30">30 comments per page</option><option value="50" selected="selected">50 comments per page</option><option value="70">70 comments per page</option><option value="90">90 comments per page</option><option value="150">150 comments per page</option><option value="200">200 comments per page</option><option value="250">250 comments per page</option><option value="300">300 comments per page</option></select>
</div>
<input type="submit" name="op" id="edit-submit" value="Save settings"  class="form-submit" />
</div><div class="description">Select your preferred way to display the comments and click "Save settings" to activate your changes.</div></div>
</div>

</div></form>
<a id="comment-1294"></a>
<div class="comment comment-published odd">

  <div class="clear-block">
      <span class="submitted">Wed, 2010-03-31 14:02 — rixius</span>
  
  
  
    <h3><a href="/licenses/bsd-license.php#comment-1294" class="active">Sub Licensing</a></h3>

    <div class="content">
      <p>If you are deriving an application from an application licensed with this new BSD license, how does the process work?<br />
the deriving is making substansial changes.</p>
          </div>
  </div>

  </div>
<form action="/licenses/bsd-license.php"  accept-charset="UTF-8" method="post" id="comment-controls-1">
<div><div class="box">

  <h2>Comment viewing options</h2>

  <div class="content"><div class="container-inline"><input type="hidden" name="form_build_id" id="form-fb3c0c95b2b71bb035a56462f724559b" value="form-fb3c0c95b2b71bb035a56462f724559b"  />
<input type="hidden" name="form_id" id="edit-comment-controls-1" value="comment_controls"  />
<div class="form-item" id="edit-mode-1-wrapper">
 <select name="mode" class="form-select" id="edit-mode-1" ><option value="1">Flat list - collapsed</option><option value="2">Flat list - expanded</option><option value="3">Threaded list - collapsed</option><option value="4" selected="selected">Threaded list - expanded</option></select>
</div>
<div class="form-item" id="edit-order-1-wrapper">
 <select name="order" class="form-select" id="edit-order-1" ><option value="1" selected="selected">Date - newest first</option><option value="2">Date - oldest first</option></select>
</div>
<div class="form-item" id="edit-comments-per-page-1-wrapper">
 <select name="comments_per_page" class="form-select" id="edit-comments-per-page-1" ><option value="10">10 comments per page</option><option value="30">30 comments per page</option><option value="50" selected="selected">50 comments per page</option><option value="70">70 comments per page</option><option value="90">90 comments per page</option><option value="150">150 comments per page</option><option value="200">200 comments per page</option><option value="250">250 comments per page</option><option value="300">300 comments per page</option></select>
</div>
<input type="submit" name="op" id="edit-submit-1" value="Save settings"  class="form-submit" />
</div><div class="description">Select your preferred way to display the comments and click "Save settings" to activate your changes.</div></div>
</div>

</div></form>
</div>
          </div>
                    <div id="footer"><a rel="license" href="http://creativecommons.org/licenses/by/2.5/"><img alt="Creative Commons License" src="http://i.creativecommons.org/l/by/2.5/88x31.png" /></a><br />Opensource.org site content is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/2.5/">Creative Commons Attribution 2.5  License</a>.
	
		
	
	|  <a href="../ToS">Terms of Service</a><div id="block-block-7" class="clear-block block block-block">


  <div class="content"><script src="http://www.google-analytics.com/urchin.js" type="text/javascript">
</script>
<script type="text/javascript">
_uacct = "UA-3916956-1";
urchinTracker();
</script></div>
</div>
</div>
      </div></div></div></div> <!-- /.left-corner, /.right-corner, /#squeeze, /#center -->

      
    </div> <!-- /container -->
  </div>
<!-- /layout -->

    </body>
</html>
